import { GraphQLNamedType } from "graphql";
import { MetadataStorage } from "./MetadataStorage";
import { ASTParser } from "../sdl/ast";
export interface DefinitionConfig {
    typeName?: string;
    description?: string;
    directives?: any;
}
/**
 * Contain configs required to build named GraphQL types.
 * Guarantee its type instance only created once.
 */
export declare class Definition<TConfig extends DefinitionConfig = DefinitionConfig> {
    static define(astParser?: ASTParser, storage?: MetadataStorage): (linkedClass: Function) => void;
    protected static decorate(astParser: ASTParser | undefined, storage: MetadataStorage, linkedClass: Function): void;
    protected readonly config: TConfig;
    constructor(config: TConfig);
    readonly typeName: string;
    readonly description: string | undefined;
    /**
     * Build GraphQLType instance from metadata.
     */
    buildTypeInstance(storage: MetadataStorage, targetClass: Function): GraphQLNamedType;
}
