"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var global_1 = require("../global");
/**
 * Contain configs required to build named GraphQL types.
 * Guarantee its type instance only created once.
 */
var Definition = /** @class */ (function () {
    function Definition(config) {
        this.config = config;
    }
    Definition.define = function (astParser, storage) {
        var _this = this;
        var targetStorage = storage || global_1.getGlobalMetadataStorage();
        return function (linkedClass) { return _this.decorate(astParser, targetStorage, linkedClass); };
    };
    Definition.decorate = function (astParser, storage, linkedClass) {
        astParser && astParser.fieldMetadataConfigs.forEach(function (config) {
            var maybeStaticResolver = linkedClass[config.field.defaultName];
            var resolver = config.resolver || (maybeStaticResolver instanceof Function ? maybeStaticResolver : undefined);
            storage.registerFieldReference(__assign({}, config, { container: linkedClass, resolver: resolver }));
        });
        astParser && astParser.inputFieldMetadataConfigs.forEach(function (config) {
            storage.registerInputFieldReference({
                container: linkedClass,
                field: config,
            });
        });
    };
    Object.defineProperty(Definition.prototype, "typeName", {
        get: function () {
            var typeName = this.config.typeName;
            if (!typeName) {
                throw new Error('Should have typeName');
            }
            return typeName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Definition.prototype, "description", {
        get: function () {
            return this.config.description;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Build GraphQLType instance from metadata.
     */
    Definition.prototype.buildTypeInstance = function (storage, targetClass) {
        throw new Error("Should implement typeInstance getter in " + this.constructor.name);
    };
    ;
    return Definition;
}());
exports.Definition = Definition;
//# sourceMappingURL=Definition.js.map