import { Definition } from './Definition';
import { Field } from '../field';
import { InputField } from '../field/InputField';
import { GraphQLNamedType, GraphQLFieldResolver } from 'graphql';
export declare class DefinitionEntry<T extends Definition = Definition> {
    key: Function;
    metadata: T;
    constructor(key: Function, metadata: T);
}
export declare class FieldReferenceEntry {
    mountName: string;
    container: Function;
    field: Field;
    resolver?: GraphQLFieldResolver<any, any>;
    constructor(values: FieldReferenceEntry);
}
export declare class InputFieldReferenceEntry {
    container: Function;
    field: InputField;
    constructor(values: InputFieldReferenceEntry);
}
/**
 * Keep all [[Definition]] and references.
 * Provide methods to query metadata with its associated class or graphql type name.
 */
export declare class MetadataStorage {
    readonly definitionMetadata: Array<DefinitionEntry<Definition>>;
    readonly memoizedTypeInstanceMap: Map<Function, GraphQLNamedType>;
    readonly fieldReferences: Array<FieldReferenceEntry>;
    readonly inputFieldReferences: Array<InputFieldReferenceEntry>;
    /**
     * Add a new [[Metadata]] object to storage.
     * @param metadata A metadata object to register
     */
    register(metadata: Definition<any>, key: Function): void;
    registerFieldReference(args: FieldReferenceEntry): void;
    registerInputFieldReference(args: InputFieldReferenceEntry): void;
    /**
     * Get a [[Definition]] object which is instance of the `metadataClass` and associated to `componentClass`
     * @param metadataClass A [[Definition]] subclass to query
     * @param componentClass A class associated with metadata to query
     */
    getDefinition<T extends Definition>(metadataClass: {
        new (...args: any[]): T;
    }, componentClass: Function): DefinitionEntry<T>;
    /**
     * Get a [[Definition]] object by the name of the GraphQLType that the metadata will generate.
     * @param name The name of a GraphQLType which will be built from metadata to query
     */
    getDefinitionByName(name: string): DefinitionEntry<any>;
    getFieldReference(resolver: Function): FieldReferenceEntry;
    queryFieldReferences(componentClass: Function): FieldReferenceEntry[];
    queryInputFieldReference(componentClass: Function): InputFieldReferenceEntry[];
}
