"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var types_1 = require("../types");
var Definition_1 = require("./Definition");
var DefinitionEntry = /** @class */ (function () {
    function DefinitionEntry(key, metadata) {
        this.key = key;
        this.metadata = metadata;
    }
    ;
    return DefinitionEntry;
}());
exports.DefinitionEntry = DefinitionEntry;
var FieldReferenceEntry = /** @class */ (function () {
    function FieldReferenceEntry(values) {
        Object.assign(this, values);
    }
    return FieldReferenceEntry;
}());
exports.FieldReferenceEntry = FieldReferenceEntry;
var InputFieldReferenceEntry = /** @class */ (function () {
    function InputFieldReferenceEntry(values) {
        Object.assign(this, values);
    }
    return InputFieldReferenceEntry;
}());
exports.InputFieldReferenceEntry = InputFieldReferenceEntry;
/**
 * Keep all [[Definition]] and references.
 * Provide methods to query metadata with its associated class or graphql type name.
 */
var MetadataStorage = /** @class */ (function () {
    function MetadataStorage() {
        this.definitionMetadata = [];
        this.memoizedTypeInstanceMap = new Map();
        this.fieldReferences = [];
        this.inputFieldReferences = [];
    }
    /**
     * Add a new [[Metadata]] object to storage.
     * @param metadata A metadata object to register
     */
    MetadataStorage.prototype.register = function (metadata, key) {
        if (metadata instanceof Definition_1.Definition) {
            this.definitionMetadata.push(new DefinitionEntry(key, metadata));
        }
        else {
            throw new Error("Cannot register to stroage: " + metadata);
        }
    };
    MetadataStorage.prototype.registerFieldReference = function (args) {
        this.fieldReferences.push(new FieldReferenceEntry(args));
    };
    MetadataStorage.prototype.registerInputFieldReference = function (args) {
        this.inputFieldReferences.push(new InputFieldReferenceEntry(args));
    };
    /**
     * Get a [[Definition]] object which is instance of the `metadataClass` and associated to `componentClass`
     * @param metadataClass A [[Definition]] subclass to query
     * @param componentClass A class associated with metadata to query
     */
    MetadataStorage.prototype.getDefinition = function (metadataClass, componentClass) {
        var entry = this.definitionMetadata.find(function (entry) { return entry.key === componentClass; });
        if (!entry) {
            throw new Error("Cannot get " + metadataClass.name + " of " + componentClass.name + " from MetadataStorage");
        }
        return entry;
    };
    /**
     * Get a [[Definition]] object by the name of the GraphQLType that the metadata will generate.
     * @param name The name of a GraphQLType which will be built from metadata to query
     */
    MetadataStorage.prototype.getDefinitionByName = function (name) {
        var entry = this.definitionMetadata.find(function (entry) { return entry.metadata.typeName === name; });
        if (!entry) {
            throw new Error("Cannot find metadata with given name: " + name);
        }
        return entry;
    };
    MetadataStorage.prototype.getFieldReference = function (resolver) {
        var entry = this.fieldReferences.find(function (entry) { return entry.resolver === resolver; });
        if (!entry) {
            throw new Error("Cannot find metadata with given function: " + resolver);
        }
        return entry;
    };
    MetadataStorage.prototype.queryFieldReferences = function (componentClass) {
        return this.fieldReferences.filter(function (entry) { return (componentClass === entry.container || types_1.isSubClassOf(componentClass, entry.container)); });
    };
    MetadataStorage.prototype.queryInputFieldReference = function (componentClass) {
        return this.inputFieldReferences.filter(function (entry) { return (componentClass === entry.container || types_1.isSubClassOf(componentClass, entry.container)); });
    };
    return MetadataStorage;
}());
exports.MetadataStorage = MetadataStorage;
//# sourceMappingURL=MetadataStorage.js.map