"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var MetadataStorage_1 = require("./base/MetadataStorage");
var TypeExpression_1 = require("./type-expression/TypeExpression");
var scalar_1 = require("./builtins/scalar");
var field_1 = require("./field");
function createMetadataStorage() {
    var storage = new MetadataStorage_1.MetadataStorage();
    scalar_1.loadBuiltInScalar(storage);
    return storage;
}
exports.createMetadataStorage = createMetadataStorage;
function getGlobalMetadataStorage() {
    if (!exports.globalMetadataStorage) {
        exports.globalMetadataStorage = createMetadataStorage();
    }
    return exports.globalMetadataStorage;
}
exports.getGlobalMetadataStorage = getGlobalMetadataStorage;
/**
 * Get a GraphQLType instance from the given storage or default
 * global metadata storage.
 * @param typeArg
 * @param storage
 */
function getGraphQLType(typeArg, maybeStorage) {
    var storage = maybeStorage || getGlobalMetadataStorage();
    var typeExpression = new TypeExpression_1.TypeExpression(typeArg);
    return typeExpression.buildTypeInstance(storage);
}
exports.getGraphQLType = getGraphQLType;
function mountField(resolver, asName, maybeStorage) {
    var storage = maybeStorage || getGlobalMetadataStorage();
    var ref = storage.getFieldReference(resolver);
    var field = ref.field;
    var mountName = asName || ref.mountName;
    return new field_1.FieldMount({ field: field, mountName: mountName, resolver: resolver });
}
exports.mountField = mountField;
//# sourceMappingURL=global.js.map