import { GraphQLObjectType, GraphQLFieldConfigMap, GraphQLInterfaceType, GraphQLFieldConfig } from "graphql";
import { Definition, DefinitionConfig } from "../base/Definition";
import { MetadataStorage, FieldReferenceEntry } from "../base/MetadataStorage";
import { TypeExpression } from "../type-expression/TypeExpression";
import { ASTParser } from "../sdl/ast";
export interface ObjectTypeConfig extends DefinitionConfig {
    description?: string;
    interfaces?: TypeExpression[];
}
/**
 * Metadata type for ObjectType
 */
export declare class ObjectType<TConfig extends ObjectTypeConfig = ObjectTypeConfig> extends Definition<TConfig> {
    protected static decorate(astParser: ASTParser | undefined, storage: MetadataStorage, linkedClass: Function): void;
    buildFieldConfig(storage: MetadataStorage, targetClass: Function, entry: FieldReferenceEntry): GraphQLFieldConfig<any, any>;
    buildFieldConfigMap(storage: MetadataStorage, targetClass: Function): GraphQLFieldConfigMap<any, any>;
    /**
     * Build GraphQLObjectType instance from metadata.
     */
    buildTypeInstance(storage: MetadataStorage, targetClass: Function): GraphQLObjectType;
    findInterfaces(storage: MetadataStorage, targetClass: Function): GraphQLInterfaceType[] | undefined;
    buildIsTypeOf(storage: MetadataStorage, targetClass: Function): (source: any) => boolean;
}
