"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var Definition_1 = require("../base/Definition");
/**
 * Metadata type for ObjectType
 */
var ObjectType = /** @class */ (function (_super) {
    __extends(ObjectType, _super);
    function ObjectType() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ObjectType.decorate = function (astParser, storage, linkedClass) {
        var _this = this;
        _super.decorate.call(this, astParser, storage, linkedClass);
        if (astParser) {
            astParser.objectTypeMetadataConfigs.forEach(function (config) {
                storage.register(new _this(config), linkedClass);
            });
        }
        else {
            storage.register(new this({ typeName: linkedClass.name }), linkedClass);
        }
    };
    ObjectType.prototype.buildFieldConfig = function (storage, targetClass, entry) {
        var _a = entry.field, description = _a.description, deprecationReason = _a.deprecationReason;
        return {
            type: entry.field.buildType(storage, targetClass),
            args: entry.field.buildArgs(storage, targetClass),
            resolve: entry.resolver,
            description: description,
            deprecationReason: deprecationReason,
        };
    };
    ObjectType.prototype.buildFieldConfigMap = function (storage, targetClass) {
        var _this = this;
        var refs = storage.queryFieldReferences(targetClass);
        return (refs.reduce(function (results, entry) {
            var name = entry.mountName;
            results[name] = _this.buildFieldConfig(storage, targetClass, entry);
            return results;
        }, {}));
    };
    /**
     * Build GraphQLObjectType instance from metadata.
     */
    ObjectType.prototype.buildTypeInstance = function (storage, targetClass) {
        var name = this.typeName || targetClass.constructor.name;
        var fields = this.buildFieldConfigMap.bind(this, storage, targetClass);
        var interfaces = this.findInterfaces(storage, targetClass);
        var description = this.description;
        var isTypeOf = this.buildIsTypeOf(storage, targetClass);
        return new graphql_1.GraphQLObjectType({ name: name, fields: fields, interfaces: interfaces, description: description, isTypeOf: isTypeOf });
    };
    ObjectType.prototype.findInterfaces = function (storage, targetClass) {
        var interfaces = this.config.interfaces;
        return interfaces && interfaces.map(function (i) { return i.buildTypeInstance(storage, targetClass); });
    };
    ObjectType.prototype.buildIsTypeOf = function (storage, targetClass) {
        return function (source) { return (source instanceof targetClass); };
    };
    return ObjectType;
}(Definition_1.Definition));
exports.ObjectType = ObjectType;
//# sourceMappingURL=ObjectType.js.map