import { DefinitionNode, FieldDefinitionNode, InputObjectTypeDefinitionNode, InputValueDefinitionNode, InterfaceTypeDefinitionNode, ListTypeNode, NamedTypeNode, NonNullTypeNode, ObjectTypeDefinitionNode } from 'graphql';
import { FieldMount } from '../field/Field';
import { InputTypeConfig } from '../metadata/InputType';
import { ObjectTypeConfig } from '../metadata/ObjectType';
import { TypeArg, TypeExpression } from '../type-expression/TypeExpression';
import { Lazy } from '../types';
import { InterfaceTypeConfig } from '../metadata/InterfaceType';
import { InputField } from '../field/InputField';
export interface SubstitutionMap {
    [tempName: string]: GQLInterpolatable;
}
export declare type GQLInterpolatable = FieldMount | Array<FieldMount> | TypeArg | TypeExpression | Lazy<TypeArg> | Lazy<TypeExpression>;
export declare function gql(strings: TemplateStringsArray, ...interpolated: Array<GQLInterpolatable>): ASTParser;
export declare class ASTParser {
    readonly objectTypeMetadataConfigs: ObjectTypeConfig[];
    readonly interfaceTypeMetadataConfigs: InterfaceTypeConfig[];
    readonly inputObjectTypeMetadataConfigs: InputTypeConfig[];
    readonly fieldMetadataConfigs: FieldMount[];
    readonly inputFieldMetadataConfigs: InputField[];
    constructor(rootNode: DefinitionNode, subsMap: SubstitutionMap);
    protected rootNode: DefinitionNode;
    protected subsMap: SubstitutionMap;
    protected createMetadataFromAST(): void;
    protected completeTypeExpression(type: NamedTypeNode | ListTypeNode | NonNullTypeNode): TypeExpression;
    protected appendObjectTypeConfig(node: ObjectTypeDefinitionNode): void;
    protected appendInterfaceTypeMetadataConfig(node: InterfaceTypeDefinitionNode): void;
    protected appendInputObjectTypeMetadataConfig(node: InputObjectTypeDefinitionNode): void;
    protected appendFieldMetadataConfig(node: FieldDefinitionNode): void;
    protected createInputField(node: InputValueDefinitionNode): InputField;
    protected appendInputFieldMetadataConfig(node: InputValueDefinitionNode): void;
}
