"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function completeDirectives(directiveNodes) {
    return directiveNodes.reduce(function (results, node) {
        if (node.arguments instanceof Array) {
            results[node.name.value] = completeArgumentsOrObjectFields(node.arguments);
        }
        else {
            results[node.name.value] = {};
        }
        return results;
    }, {});
}
exports.completeDirectives = completeDirectives;
function completeArgumentsOrObjectFields(nodes) {
    return nodes.reduce(function (results, node) {
        results[node.name.value] = completeValueNode(node.value);
        return results;
    }, {});
}
function completeValueNode(node) {
    if (node.kind === 'ObjectValue') {
        return completeArgumentsOrObjectFields(node.fields);
    }
    else if (node.kind === 'NullValue') {
        return null;
    }
    else if (node.kind === 'ListValue') {
        return node.values.map(completeValueNode);
    }
    else if (node.kind === 'Variable') {
        throw new Error("Cannot use variable in schema directives: " + node.name);
    }
    else if (node.kind === 'IntValue' || node.kind === 'FloatValue') {
        return Number(node.value);
    }
    return node.value;
}
exports.completeValueNode = completeValueNode;
//# sourceMappingURL=directive.js.map