"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var types_1 = require("../types");
var Definition_1 = require("../base/Definition");
var formatObjectInfo_1 = require("../utilities/formatObjectInfo");
/**
 * Contain an argument which can be resolved to GraphQLType instance.
 */
var TypeExpression = /** @class */ (function () {
    function TypeExpression(typeOption) {
        this.typeArg = typeOption;
    }
    TypeExpression.prototype.resolve = function (targetClass) {
        var typeArg = this.typeArg;
        if (types_1.isLazy(typeArg)) {
            var resolved = typeArg(targetClass);
            if (resolved instanceof TypeExpression) {
                return resolved.resolve(targetClass);
            }
            return new TypeExpression(resolved);
        }
        else {
            if (typeArg instanceof TypeExpression) {
                return typeArg.resolve(targetClass);
            }
            else {
                return this;
            }
        }
    };
    TypeExpression.prototype.getDefinitionEntry = function (storage) {
        if (this.typeArg instanceof Function) {
            return storage.getDefinition(Definition_1.Definition, this.typeArg);
        }
        else if (typeof this.typeArg === 'string') {
            return storage.getDefinitionByName(this.typeArg);
        }
        else {
            throw new Error("Cannot find any Definition with TypeExpression of " + formatObjectInfo_1.formatObjectInfo(this.typeArg));
        }
    };
    TypeExpression.prototype.buildTypeInstance = function (storage, targetClass) {
        var resolvedTypeExpression = this.resolve(targetClass);
        if (this !== resolvedTypeExpression) {
            return resolvedTypeExpression.buildTypeInstance(storage, targetClass);
        }
        if (graphql_1.isType(resolvedTypeExpression.typeArg)) {
            return resolvedTypeExpression.typeArg;
        }
        var entry = resolvedTypeExpression.getDefinitionEntry(storage);
        var typeInstance = storage.memoizedTypeInstanceMap.get(entry.key);
        if (!typeInstance) {
            var typeMetadata = storage.getDefinition(Definition_1.Definition, entry.key);
            if (!typeMetadata) {
                throw new Error("Given class " + entry.key.name + " has no corresponding metadata");
            }
            typeInstance = typeMetadata.metadata.buildTypeInstance(storage, entry.key);
            storage.memoizedTypeInstanceMap.set(entry.key, typeInstance);
        }
        return typeInstance;
    };
    return TypeExpression;
}());
exports.TypeExpression = TypeExpression;
//# sourceMappingURL=TypeExpression.js.map